# frozen_string_literal: true

require 'rails_helper'

describe Admin::DashboardHelper do
  describe '#dashboard_data' do
    it 'includes Docker-related data' do
      expect(dashboard_data).to include(:docker)
    end
  end

  describe '#docker_data' do
    before do
      FactoryBot.create(:ruby)
      dcp = instance_double 'docker_container_pool'
      allow(Runner).to receive(:strategy_class).and_return dcp
      allow(dcp).to receive(:pool_size).and_return([])
    end

    it 'contains an entry for every execution environment' do
      expect(docker_data.length).to eq(ExecutionEnvironment.count)
    end

    it 'contains the pool size for every execution environment' do
      expect(docker_data.first.symbolize_keys).to include(:pool_size)
    end

    it 'contains the number of available containers for every execution environment' do
      expect(docker_data.first).to include(:quantity)
    end
  end
end
